==> climate_toolbox-0.1.4.tar.gz: climate_toolbox-0.1.4/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    'Click>=6.0',
    # TODO: put package requirements here
]

setup_requirements = [
    'pytest-runner',
    # TODO(jgerardsimcock): put setup requirements
    # (distutils extensions, etc.) here
]

test_requirements = [
    'pytest',
    # TODO: put package test requirements here
]

setup(
    name='climate_toolbox',
    version='0.1.4',
    description="Tools for climate data wrangling",
    long_description=readme + '\n\n' + history,
    author="Justin Simcock",
    author_email='jsimcock@rhg.com',
    url='https://github.com/ClimateImpactLab/climate_toolbox',
    packages=find_packages(include=['climate_toolbox']),
    entry_points={
        'console_scripts': [
            'climate_toolbox=climate_toolbox.cli:main'
        ]
    },
    include_package_data=True,
    install_requires=requirements,
    license="MIT license",
    zip_safe=False,
    keywords='climate_toolbox',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    test_suite='tests',
    tests_require=test_requirements,
    setup_requires=setup_requirements,
)

==> climate_toolbox-0.1.5.tar.gz: climate_toolbox-0.1.5/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages
from description import long_description

requirements = [
    'Click>=6.0',
    # TODO: put package requirements here
]

setup_requirements = [
    'pytest-runner',
    # TODO(jgerardsimcock): put setup requirements
    # (distutils extensions, etc.) here
]

test_requirements = [
    'pytest',
    # TODO: put package test requirements here
]

setup(
    name='climate_toolbox',
    version='0.1.5',
    description="Tools for climate data wrangling",
    long_description=long_description,
    author="Justin Simcock",
    author_email='jsimcock@rhg.com',
    url='https://github.com/ClimateImpactLab/climate_toolbox',
    packages=find_packages(include=['climate_toolbox']),
    entry_points={
        'console_scripts': [
            'climate_toolbox=climate_toolbox.cli:main'
        ]
    },
    include_package_data=True,
    install_requires=requirements,
    license="MIT license",
    zip_safe=False,
    keywords='climate_toolbox',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    test_suite='tests',
    tests_require=test_requirements,
    setup_requires=setup_requirements,
)
